@@ -166,9 +166,10 @@ landscape.new.local.demo <- function(rland,S,R,M,k=0)
     {
       stop("Matricies do not conform to stages set in intparam!")
     }
-} #end if k==0
- else{ #k==1; matrix at carrying capacity
-   if (is.null(rland$demography$localdemK))
+  } #end if k==0
+
+  else{ #k==1; matrix at carrying capacity
+  if (is.null(rland$demography$localdemK))
     {
       rland$demography$localdemK <- list(NULL)
       demonumK <- 1
@@ -308,43 +309,43 @@ landscape.new.epoch <- function(rland,S=NULL,R=NULL,M=NULL,epochprob=1,startgen=
 # populates elements in the landscape matrices (S,R,M) in such a way that migration behaves
 # like wright's island model.
 
-#landscape.new.epoch.island <- function(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
-#                             epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
-#{
-#  stages <- rland$intparam$stages
-#  matrixsize <- rland$intparam$habitats * stages
-#
-#  if  (!((length(sfrom) == stages) && (length(sto) == stages) &&
-#         (length(mfrom) == stages) && (length(mto) == stages) &&
-#         (length(ffrom) == stages) && (length(fto) == stages)))
-#    {
-#      stop("from and to vectors not the correct length")
-#    }
-#
-#  S <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
-#  R <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
-#  M <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
-#
-#  for (i in 1:matrixsize)
-#    for (j in 1:matrixsize)
-#      {
-#        toindex <- ((i-1) %% stages) + 1
-#        fromindex <- ((j-1) %% stages) + 1
-#        if (sfrom[fromindex] && sto[toindex])
-#          S[i, j] <- s
-#        if (mfrom[fromindex] && mto[toindex])
-#          R[i, j] <- m
-#        if (ffrom[fromindex] && fto[toindex])
-#          M[i, j] <- f
-#      }
-#
-#  rland <- landscape.new.epoch(rland,S,R,M,epochprob,startgen,extinct,carry,localprob)
+landscape.new.epoch.island <- function(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
+                             epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
+{
+  stages <- rland$intparam$stages
+  matrixsize <- rland$intparam$habitats * stages
+
+  if  (!((length(sfrom) == stages) && (length(sto) == stages) &&
+         (length(mfrom) == stages) && (length(mto) == stages) &&
+         (length(ffrom) == stages) && (length(fto) == stages)))
+    {
+      stop("from and to vectors not the correct length")
+    }
+
+  S <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
+  R <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
+  M <- matrix(rep(0, (matrixsize * matrixsize)), nrow = matrixsize, ncol = matrixsize)
+
+  for (i in 1:matrixsize)
+    for (j in 1:matrixsize)
+      {
+        toindex <- ((i-1) %% stages) + 1
+        fromindex <- ((j-1) %% stages) + 1
+        if (sfrom[fromindex] && sto[toindex])
+          S[i, j] <- s
+        if (mfrom[fromindex] && mto[toindex])
+          R[i, j] <- m
+        if (ffrom[fromindex] && fto[toindex])
+          M[i, j] <- f
+      }
+
+  rland <- landscape.new.epoch(rland,S,R,M,epochprob,startgen,extinct,carry,localprob)
 #  rland$demography$epochs[[1]]$S <- S
 #  rland$demography$epochs[[1]]$R <- R
 #  rland$demography$epochs[[1]]$M <- M
-#
-#  rland
-#}
+
+  rland
+}
 
 
 
@@ -354,30 +355,31 @@ landscape.new.epoch <- function(rland,S=NULL,R=NULL,M=NULL,epochprob=1,startgen=
 # populates elements in the landscape matrices (S,R,M) in such a way that migration behaves
 # like wright's island model.
 
-#landscape.new.epoch.step <- function(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
-#                             epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
-#{
-#
-#  rland <- landscape.new.epoch.island(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
-#                            epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
-#  if (rland$intparam$habitats>2)
-#    {
-#      for (i in 1:rland$intparam$habitats)
-#        for (j in 1:rland$intparam$habitats)
-#          {
-#            if (!j %in% c(-1,0,1)*i)
-#              {
-#                rland$epochs[[length(rland$epochs)]]$S[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
-#                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
-#                rland$epochs[[length(rland$epochs)]]$R[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
-#                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
-#                rland$epochs[[length(rland$epochs)]]$M[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
-#                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
-#              }
-#          }
-#    }
-#  rland
-#}
+landscape.new.epoch.step <- function(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
+                             epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
+{
+
+  rland <- landscape.new.epoch.island(rland,s,sfrom,sto,m,mfrom,mto,f,ffrom,fto,
+                            epochprob=1,startgen=0,extinct=NULL,carry=NULL,localprob=NULL)
+  if (rland$intparam$habitats>2)
+    {
+      for (i in 1:rland$inparam$habitats)
+        for (j in 1:rland$inparam$habitats)
+          {
+            if (!j %in% c(-1,0,1)*i)
+              {
+                rland$epochs[[length(rland$epochs)]]$S[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
+                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
+                rland$epochs[[length(rland$epochs)]]$R[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
+                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
+                rland$epochs[[length(rland$epochs)]]$M[rland$intparam$stages*(i-1)+(1:rland$intparam$stages),rland$intparam$stages*(j-1)+(1:rland$intparam$stages)] <-
+                  matrix(0,nrow=rland$intparam$stages,ncol=rland$intparam$stages)
+              }
+            
+          }
+    }
+  rland
+}
 
 #
 # landscape.new.locus
@@ -412,20 +414,20 @@ landscape.new.locus <- function (rland, type = 0, ploidy = 1, mutationrate = 0,
     }
     rland$intparam$locusnum <- locusnum
     if (type >= 0 && type <= 2) {
-        rland$loci[[locusnum]]$type <- as.integer(typelookup(type))
+        rland$loci[[locusnum]]$type <- typelookup(type)
     }
     else {
         stop("Invalid type of locus")
     }
     if (ploidy == 1 || ploidy == 2) {
-        rland$loci[[locusnum]]$ploidy <- as.integer(ploidy)
+        rland$loci[[locusnum]]$ploidy <- ploidy
     }
     else {
         stop("Invalid ploidy count")
     }
     rland$loci[[locusnum]]$rate <- mutationrate
     if (transmission == 0 || transmission == 1) {
-        rland$loci[[locusnum]]$trans <- as.integer(transmission)
+        rland$loci[[locusnum]]$trans <- transmission
     }
     else {
         stop("Invalid transmission number")
@@ -467,15 +469,15 @@ makealleles <- function(type,numalleles,allelesize,frequencies,states)
       retval <- vector("list", numalleles)
       for (x in 1:numalleles)
         {
-          retval[[x]]$aindex <- as.integer(x)
-          retval[[x]]$birth <- as.integer(0)
+          retval[[x]]$aindex <- x 
+          retval[[x]]$birth <- 0
           retval[[x]]$prop <- frequencies[x]
           if (is.null(states))
             {
-              retval[[x]]$state <- as.integer(x)
+              retval[[x]]$state <- x
             } else
           {
-            retval[[x]]$state <- as.integer(states[x])
+            retval[[x]]$state <- states[x]
           }
         }
     }
@@ -484,8 +486,8 @@ makealleles <- function(type,numalleles,allelesize,frequencies,states)
       retval <- vector("list", numalleles)
       for (x in 1:numalleles)
         {
-          retval[[x]]$aindex <- as.integer(x)
-          retval[[x]]$birth <- as.integer(0)
+          retval[[x]]$aindex <- x 
+          retval[[x]]$birth <- 0
           retval[[x]]$prop <- frequencies[x]
           if (is.null(states))
             {
@@ -523,7 +525,6 @@ geneseq <- function(size)
 
 landscape.new.individuals <- function(rland, PopulationSizes)
   {
-    rland <- landscape.coerce(rland,noind=T)
     rland <- .Call("populate_Rland",rland,PopulationSizes,PACKAGE="rmetasim")
     rland
   }
